# (c) 2017 VirtaMed AG - Strictly Confidential - All rights reserved
#
# This document contains unpublished, confidential and proprietary information
# of VirtaMed AG. No disclosure or use of any portion of the contents of these
# materials may be made without the express consent of VirtaMed AG.

from conans import ConanFile, CMake, tools
from conans.tools import download
from conans.tools import replace_in_file
from conans.tools import unzip
from conans import CMake
import os
import shutil


class HidapiConan(ConanFile):
    name = "hidapi"
    version = "2017.10"
    git_hash = "a6a622ffb680c55da0de787ff93b80280498330f"
    description = "A Simple library for communicating with USB and Bluetooth HID devices on Linux, Mac, and Windows. http://www.signal11.us/oss/hidapi/"
    url = "https://github.com/signal11/hidapi.git"
    source_root = "hidapi"
    license = "https://github.com/signal11/hidapi/blob/master/LICENSE.txt"
    options = {
        "fPIC": [True, False]
        ,"include_pdbs": [True, False]
    }
    default_options = "fPIC=False", "include_pdbs=False"
    settings = "os", "compiler", "build_type", "arch"
    generators = "cmake"
    patch_file = "hid.gitpatch"
    exports = ["CMakeLists.txt", patch_file]

    def source(self):
        self.run("git clone %s" % self.url)
        self.run("cd %s && git checkout %s" % (self.source_root, self.git_hash))
        self.run("cd %s && git apply %s" % (self.source_root, os.path.join(self.source_folder, self.patch_file)))

        shutil.copy("CMakeLists.txt", self.source_root)

    def config_options(self):
        if self.settings.compiler == "Visual Studio":
            self.options.remove("fPIC")
            self.settings.remove("build_type")
            self.settings.compiler["Visual Studio"].remove("runtime")
        else:
            try:  # It might have already been removed if required by more than 1 package
                del self.options.include_pdbs
            except:
                pass

    def build(self):
        cmake = CMake(self)
        defs = {}
        if self.settings.os == "Linux" and self.options.fPIC:
            defs["CMAKE_POSITION_INDEPENDENT_CODE:BOOL"] = "on"
        cmake.configure(source_dir=self.source_folder + "/" + self.source_root, defs=defs)

        if cmake.is_multi_configuration:
            self.run("cmake --build . --config Debug")
            self.run("cmake --build . --config Release")
        else:
            cmake.build()


    def package(self):
        self.copy("*.h", dst="include", src="hidapi/hidapi", keep_path=False)
        self.copy("*.lib", dst="lib", keep_path=False)
        self.copy("*.a", dst="lib", keep_path=False)
        
        if self.settings.compiler == "Visual Studio" and self.options.include_pdbs:
            self.copy(pattern="*.pdb", dst="lib", src=".", keep_path=False)
        
    def package_info(self):
        if self.settings.os != "Linux":
            self.cpp_info.debug.libs = ['hidapid']
            self.cpp_info.release.libs = ['hidapi']
        else:
            self.cpp_info.libs =  ['hidapi']

        if self.settings.os != "Linux":
            self.cpp_info.libs.append("setupapi")
        else:
            self.cpp_info.libs.append("usb-1.0")
            self.cpp_info.libs.append("pthread")
